You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by ds...@apache.org on 2016/09/15 21:01:58 UTC

[41/76] [abbrv] [partial] incubator-geode git commit: GEODE-37 changed import to org.apache.geode

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/Region.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionAccessException.java b/geode-core/src/main/java/org/apache/geode/cache/RegionAccessException.java
index 9d9ebd8..017f2d7 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionAccessException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionAccessException.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.*;
 import java.util.*;
-import com.gemstone.gemfire.distributed.Role;
-import com.gemstone.gemfire.distributed.internal.membership.InternalRole;
+import org.apache.geode.distributed.Role;
+import org.apache.geode.distributed.internal.membership.InternalRole;
 
 /**
  * Indicates that an attempt to access the region has failed.  Failure is

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/RegionAttributes.java
index b0d09fa..8435842 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionAttributes.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.File;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.client.Pool;
-import com.gemstone.gemfire.compression.Compressor;
+import org.apache.geode.cache.client.Pool;
+import org.apache.geode.compression.Compressor;
 
 /** Defines attributes for configuring a region.
  * These are <code>EvictionAttributes</code>,
@@ -39,7 +39,7 @@ import com.gemstone.gemfire.compression.Compressor;
  * @see AttributesFactory
  * @see AttributesMutator
  * @see Region#getAttributes
- * @see com.gemstone.gemfire.cache.EvictionAttributes
+ * @see org.apache.geode.cache.EvictionAttributes
  * @since GemFire 2.0
  */
 public interface RegionAttributes<K,V> {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionDestroyedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionDestroyedException.java b/geode-core/src/main/java/org/apache/geode/cache/RegionDestroyedException.java
index e518444..5c173eb 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionDestroyedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionDestroyedException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates that the region has been destroyed. Further operations

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionDistributionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionEvent.java b/geode-core/src/main/java/org/apache/geode/cache/RegionEvent.java
index 08365d5..8cb0488 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionEvent.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Contains information about an event affecting a region, including
  * its identity and the circumstances of the event.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionExistsException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionExistsException.java b/geode-core/src/main/java/org/apache/geode/cache/RegionExistsException.java
index 91225ec..288dfe3 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionExistsException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionExistsException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates that the requested region already exists when a region is

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionFactory.java b/geode-core/src/main/java/org/apache/geode/cache/RegionFactory.java
index 4fe8ee2..e4fb914 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionFactory.java
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.File;
 import java.util.Properties;
 
-import com.gemstone.gemfire.cache.client.PoolManager;
-import com.gemstone.gemfire.compression.Compressor;
-import com.gemstone.gemfire.distributed.LeaseExpiredException;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.LocalRegion;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.cache.client.PoolManager;
+import org.apache.geode.compression.Compressor;
+import org.apache.geode.distributed.LeaseExpiredException;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.LocalRegion;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * <code>RegionFactory</code> is used to create {@link Region regions}

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionMembershipListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionReinitializedException.java b/geode-core/src/main/java/org/apache/geode/cache/RegionReinitializedException.java
index 48079ea..d4f2841 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionReinitializedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionReinitializedException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates that the region has been reinitialized. Further operations

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionRoleException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionRoleException.java b/geode-core/src/main/java/org/apache/geode/cache/RegionRoleException.java
index 6e1c8db..4d12507 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionRoleException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionRoleException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates that a {@link Region} reliability failure has occurred.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionRoleListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionRoleListener.java b/geode-core/src/main/java/org/apache/geode/cache/RegionRoleListener.java
index 96df589..589d1b3 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionRoleListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionRoleListener.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * A listener that can be implemented to handle region reliability membership 
@@ -22,7 +22,7 @@ package com.gemstone.gemfire.cache;
  * required roles as defined by the region's {@link MembershipAttributes}.
  * <p>
  * Instead of implementing this interface it is recommended that you extend
- * the {@link com.gemstone.gemfire.cache.util.RegionRoleListenerAdapter} 
+ * the {@link org.apache.geode.cache.util.RegionRoleListenerAdapter} 
  * class.
  * 
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionService.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionService.java b/geode-core/src/main/java/org/apache/geode/cache/RegionService.java
index 186c41d..594e8b9 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionService.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionService.java
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Properties;
 import java.util.Set;
 
-import com.gemstone.gemfire.CancelCriterion;
-import com.gemstone.gemfire.cache.client.ClientCacheFactory;
-import com.gemstone.gemfire.cache.client.ClientCache;
-import com.gemstone.gemfire.cache.query.QueryService;
-import com.gemstone.gemfire.pdx.PdxInstance;
-import com.gemstone.gemfire.pdx.PdxInstanceFactory;
+import org.apache.geode.CancelCriterion;
+import org.apache.geode.cache.client.ClientCacheFactory;
+import org.apache.geode.cache.client.ClientCache;
+import org.apache.geode.cache.query.QueryService;
+import org.apache.geode.pdx.PdxInstance;
+import org.apache.geode.pdx.PdxInstanceFactory;
 
 /**
  * A RegionService provides access to existing {@link Region regions} that exist

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionShortcut.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionShortcut.java b/geode-core/src/main/java/org/apache/geode/cache/RegionShortcut.java
index e9c5bb4..f61bcf1 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionShortcut.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionShortcut.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Each enum represents a predefined {@link RegionAttributes} in a {@link Cache}.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RemoteTransactionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RemoteTransactionException.java b/geode-core/src/main/java/org/apache/geode/cache/RemoteTransactionException.java
index 060ffa5..0ce0398 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RemoteTransactionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RemoteTransactionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates that an unexpected runtime exception occurred

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RequiredRoles.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/ResourceException.java b/geode-core/src/main/java/org/apache/geode/cache/ResourceException.java
index 8670f0d..e5cc0c5 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/ResourceException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/ResourceException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * A Generic exception to indicate that a resource exception has occurred.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/ResumptionAction.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/ResumptionAction.java b/geode-core/src/main/java/org/apache/geode/cache/ResumptionAction.java
index 4201dce..164348b 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/ResumptionAction.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/ResumptionAction.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.io.*;
 import java.util.*;
@@ -25,7 +25,7 @@ import java.util.*;
  * Specifies how the region is affected by resumption of reliability when
  * one or more missing required roles return to the distributed membership.  
  * The <code>ResumptionAction</code> is specified when configuring a region's 
- * {@link com.gemstone.gemfire.cache.MembershipAttributes}.
+ * {@link org.apache.geode.cache.MembershipAttributes}.
  * 
  * @deprecated this API is scheduled to be removed
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RoleEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RoleEvent.java b/geode-core/src/main/java/org/apache/geode/cache/RoleEvent.java
index 734843d..88b9a2b 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RoleEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RoleEvent.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.util.Set;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RoleException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RoleException.java b/geode-core/src/main/java/org/apache/geode/cache/RoleException.java
index 467469a..524e556 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RoleException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RoleException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * <code>RoleException</code> is the superclass of those exceptions

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/Scope.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/Scope.java b/geode-core/src/main/java/org/apache/geode/cache/Scope.java
index 0ea7fa5..dcf79ef 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/Scope.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/Scope.java
@@ -16,9 +16,9 @@
  */
 
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.io.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/SerializedCacheValue.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/SerializedCacheValue.java b/geode-core/src/main/java/org/apache/geode/cache/SerializedCacheValue.java
index 3976693..4ba30e2 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/SerializedCacheValue.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/SerializedCacheValue.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Class <code>SerializedCacheValue</code> represents a serialized cache value.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/StatisticsDisabledException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/StatisticsDisabledException.java b/geode-core/src/main/java/org/apache/geode/cache/StatisticsDisabledException.java
index d2d4d35..bb31ca4 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/StatisticsDisabledException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/StatisticsDisabledException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Thrown if statistics are requested when statistics are disabled on the

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/SubscriptionAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/SubscriptionAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/SubscriptionAttributes.java
index 2e10da8..c7e1e46 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/SubscriptionAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/SubscriptionAttributes.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.DataSerializable;
+import org.apache.geode.DataSerializable;
 import java.io.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/SynchronizationCommitConflictException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/SynchronizationCommitConflictException.java b/geode-core/src/main/java/org/apache/geode/cache/SynchronizationCommitConflictException.java
index aea1f8f..721ee2a 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/SynchronizationCommitConflictException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/SynchronizationCommitConflictException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Thrown when a commit operation of a JTA enlisted cache transaction fails
  *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TimeoutException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNodeHasDepartedException.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNodeHasDepartedException.java
index 40465f6..cfe9e02 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNodeHasDepartedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNodeHasDepartedException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Thrown when the transactional data host has shutdown or no longer has the data

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNotColocatedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNotColocatedException.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNotColocatedException.java
index 09428af..50dafe6 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNotColocatedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNotColocatedException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates that an attempt was made to transactionally modify multiple keys that

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionDataRebalancedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionDataRebalancedException.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionDataRebalancedException.java
index 1d61b74..f82fdae 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionDataRebalancedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionDataRebalancedException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.cache.control.RebalanceOperation;
+import org.apache.geode.cache.control.RebalanceOperation;
 
 /**
  * Thrown when a {@link RebalanceOperation} occurs concurrently with a transaction.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionEvent.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionEvent.java
index 5bf0c56..856e8be 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionEvent.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 import java.util.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionException.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionException.java
index ef0999d..7c022aa 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * This is the superclass for all Exceptions that may be thrown

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionId.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionId.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionId.java
index 230a649..87cee7c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionId.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionId.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.Externalizable;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionInDoubtException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionInDoubtException.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionInDoubtException.java
index 7718b0c..e67d3a7 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionInDoubtException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionInDoubtException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * This Exception is thrown in presence of node failures, when GemFire cannot

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionListener.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionListener.java
index 9cbc5f8..1555357 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionListener.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * <p>A listener that can be implemented to handle transaction related

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionWriter.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionWriter.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionWriter.java
index 848b39b..f071d24 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionWriter.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionWriter.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionWriterException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TransactionWriterException.java b/geode-core/src/main/java/org/apache/geode/cache/TransactionWriterException.java
index 0a0b182..f59eb38 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/TransactionWriterException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TransactionWriterException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/UnsupportedOperationInTransactionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/UnsupportedOperationInTransactionException.java b/geode-core/src/main/java/org/apache/geode/cache/UnsupportedOperationInTransactionException.java
index d460d12..1afa16f 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/UnsupportedOperationInTransactionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/UnsupportedOperationInTransactionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * Indicates that an attempt was mode to invoke an operation that is not

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/UnsupportedVersionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/UnsupportedVersionException.java b/geode-core/src/main/java/org/apache/geode/cache/UnsupportedVersionException.java
index 29cde1b..28bb032 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/UnsupportedVersionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/UnsupportedVersionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /**
  * An <code>UnsupportedVersionException</code> indicates an unsupported version.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/VersionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/VersionException.java b/geode-core/src/main/java/org/apache/geode/cache/VersionException.java
index 59208cc..d497a68 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/VersionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/VersionException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.GemFireCheckedException;
+import org.apache.geode.GemFireCheckedException;
 
 /**
  * An <code>VersionException</code> is an exception that indicates

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEvent.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEvent.java
index 9e05334..6d20fb2 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEvent.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue;
+package org.apache.geode.cache.asyncqueue;
 
-import com.gemstone.gemfire.cache.wan.EventSequenceID;
-import com.gemstone.gemfire.cache.wan.GatewayQueueEvent;
+import org.apache.geode.cache.wan.EventSequenceID;
+import org.apache.geode.cache.wan.GatewayQueueEvent;
 
 /**
  * Represents <code>Cache</code> events delivered to <code>AsyncEventListener</code>.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventListener.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventListener.java
index b8661b5..7b0811c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventListener.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.asyncqueue;
+package org.apache.geode.cache.asyncqueue;
 
 import java.util.List;
 
-import com.gemstone.gemfire.cache.CacheCallback;
+import org.apache.geode.cache.CacheCallback;
 
 /**
  * A callback for events passing through the <code>AsyncEventQueue</code> to which this

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueue.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueue.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueue.java
index 85ca392..b0658e4 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueue.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueue.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue;
+package org.apache.geode.cache.asyncqueue;
 
 import java.util.List;
 
-import com.gemstone.gemfire.cache.wan.GatewayEventFilter;
-import com.gemstone.gemfire.cache.wan.GatewayEventSubstitutionFilter;
-import com.gemstone.gemfire.cache.wan.GatewaySender.OrderPolicy;
+import org.apache.geode.cache.wan.GatewayEventFilter;
+import org.apache.geode.cache.wan.GatewayEventSubstitutionFilter;
+import org.apache.geode.cache.wan.GatewaySender.OrderPolicy;
 
 /**
  * Interface of AsyncEventQueue. 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueueFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueueFactory.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueueFactory.java
index 3540ce3..3087b12 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueueFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEventQueueFactory.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue;
+package org.apache.geode.cache.asyncqueue;
 
 import java.util.List;
 
-import com.gemstone.gemfire.cache.wan.GatewayEventFilter;
-import com.gemstone.gemfire.cache.wan.GatewayEventSubstitutionFilter;
-import com.gemstone.gemfire.cache.wan.GatewaySender.OrderPolicy;
-import com.gemstone.gemfire.cache.wan.GatewaySenderFactory;
+import org.apache.geode.cache.wan.GatewayEventFilter;
+import org.apache.geode.cache.wan.GatewayEventSubstitutionFilter;
+import org.apache.geode.cache.wan.GatewaySender.OrderPolicy;
+import org.apache.geode.cache.wan.GatewaySenderFactory;
 
 /**
  * Factory to create the <code>AsyncEventQueue</code>. 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueFactoryImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueFactoryImpl.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueFactoryImpl.java
index f658621..663a565 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueFactoryImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueFactoryImpl.java
@@ -14,31 +14,31 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue.internal;
+package org.apache.geode.cache.asyncqueue.internal;
 
-import com.gemstone.gemfire.internal.cache.wan.AsyncEventQueueConfigurationException;
+import org.apache.geode.internal.cache.wan.AsyncEventQueueConfigurationException;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventListener;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventQueue;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventQueueFactory;
-import com.gemstone.gemfire.cache.wan.GatewayEventFilter;
-import com.gemstone.gemfire.cache.wan.GatewayEventSubstitutionFilter;
-import com.gemstone.gemfire.cache.wan.GatewaySender;
-import com.gemstone.gemfire.cache.wan.GatewaySender.OrderPolicy;
-import com.gemstone.gemfire.cache.wan.GatewaySenderFactory;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.wan.GatewaySenderAttributes;
-import com.gemstone.gemfire.internal.cache.xmlcache.AsyncEventQueueCreation;
-import com.gemstone.gemfire.internal.cache.xmlcache.CacheCreation;
-import com.gemstone.gemfire.internal.cache.xmlcache.ParallelAsyncEventQueueCreation;
-import com.gemstone.gemfire.internal.cache.xmlcache.ParallelGatewaySenderCreation;
-import com.gemstone.gemfire.internal.cache.xmlcache.SerialAsyncEventQueueCreation;
-import com.gemstone.gemfire.internal.cache.xmlcache.SerialGatewaySenderCreation;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.asyncqueue.AsyncEventListener;
+import org.apache.geode.cache.asyncqueue.AsyncEventQueue;
+import org.apache.geode.cache.asyncqueue.AsyncEventQueueFactory;
+import org.apache.geode.cache.wan.GatewayEventFilter;
+import org.apache.geode.cache.wan.GatewayEventSubstitutionFilter;
+import org.apache.geode.cache.wan.GatewaySender;
+import org.apache.geode.cache.wan.GatewaySender.OrderPolicy;
+import org.apache.geode.cache.wan.GatewaySenderFactory;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.wan.GatewaySenderAttributes;
+import org.apache.geode.internal.cache.xmlcache.AsyncEventQueueCreation;
+import org.apache.geode.internal.cache.xmlcache.CacheCreation;
+import org.apache.geode.internal.cache.xmlcache.ParallelAsyncEventQueueCreation;
+import org.apache.geode.internal.cache.xmlcache.ParallelGatewaySenderCreation;
+import org.apache.geode.internal.cache.xmlcache.SerialAsyncEventQueueCreation;
+import org.apache.geode.internal.cache.xmlcache.SerialGatewaySenderCreation;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
 
 public class AsyncEventQueueFactoryImpl implements AsyncEventQueueFactory {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueImpl.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueImpl.java
index 994bbfc..1a9e893 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueImpl.java
@@ -14,22 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue.internal;
+package org.apache.geode.cache.asyncqueue.internal;
 
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventListener;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventQueue;
-import com.gemstone.gemfire.cache.wan.GatewayEventFilter;
-import com.gemstone.gemfire.cache.wan.GatewayEventSubstitutionFilter;
-import com.gemstone.gemfire.cache.wan.GatewaySender;
-import com.gemstone.gemfire.cache.wan.GatewaySender.OrderPolicy;
-import com.gemstone.gemfire.internal.cache.RegionQueue;
-import com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySender;
-import com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySenderEventProcessor;
-import com.gemstone.gemfire.internal.cache.wan.serial.ConcurrentSerialGatewaySenderEventProcessor;
+import org.apache.geode.cache.asyncqueue.AsyncEventListener;
+import org.apache.geode.cache.asyncqueue.AsyncEventQueue;
+import org.apache.geode.cache.wan.GatewayEventFilter;
+import org.apache.geode.cache.wan.GatewayEventSubstitutionFilter;
+import org.apache.geode.cache.wan.GatewaySender;
+import org.apache.geode.cache.wan.GatewaySender.OrderPolicy;
+import org.apache.geode.internal.cache.RegionQueue;
+import org.apache.geode.internal.cache.wan.AbstractGatewaySender;
+import org.apache.geode.internal.cache.wan.AbstractGatewaySenderEventProcessor;
+import org.apache.geode.internal.cache.wan.serial.ConcurrentSerialGatewaySenderEventProcessor;
 
 public class AsyncEventQueueImpl implements AsyncEventQueue {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java
index e9e1e0b..61eeca9 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue.internal;
+package org.apache.geode.cache.asyncqueue.internal;
 
-import com.gemstone.gemfire.StatisticDescriptor;
-import com.gemstone.gemfire.StatisticsFactory;
-import com.gemstone.gemfire.StatisticsType;
-import com.gemstone.gemfire.StatisticsTypeFactory;
-import com.gemstone.gemfire.internal.statistics.StatisticsTypeFactoryImpl;
-import com.gemstone.gemfire.internal.cache.wan.GatewaySenderStats;
+import org.apache.geode.StatisticDescriptor;
+import org.apache.geode.StatisticsFactory;
+import org.apache.geode.StatisticsType;
+import org.apache.geode.StatisticsTypeFactory;
+import org.apache.geode.internal.statistics.StatisticsTypeFactoryImpl;
+import org.apache.geode.internal.cache.wan.GatewaySenderStats;
 
 public class AsyncEventQueueStats extends GatewaySenderStats {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/ParallelAsyncEventQueueImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/ParallelAsyncEventQueueImpl.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/ParallelAsyncEventQueueImpl.java
index 4b708b8..e24a070 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/ParallelAsyncEventQueueImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/ParallelAsyncEventQueueImpl.java
@@ -14,35 +14,35 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue.internal;
+package org.apache.geode.cache.asyncqueue.internal;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.EntryOperation;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventListener;
-import com.gemstone.gemfire.cache.wan.GatewayTransportFilter;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.distributed.internal.ResourceEvent;
-import com.gemstone.gemfire.distributed.internal.DistributionAdvisor.Profile;
-import com.gemstone.gemfire.internal.cache.DistributedRegion;
-import com.gemstone.gemfire.internal.cache.EntryEventImpl;
-import com.gemstone.gemfire.internal.cache.EventID;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.PartitionedRegionHelper;
-import com.gemstone.gemfire.internal.cache.UpdateAttributesProcessor;
-import com.gemstone.gemfire.internal.cache.ha.ThreadIdentifier;
-import com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySender;
-import com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySenderEventProcessor;
-import com.gemstone.gemfire.internal.cache.wan.GatewaySenderAttributes;
-import com.gemstone.gemfire.internal.cache.wan.parallel.ConcurrentParallelGatewaySenderEventProcessor;
-import com.gemstone.gemfire.internal.cache.wan.parallel.ConcurrentParallelGatewaySenderQueue;
-import com.gemstone.gemfire.internal.cache.wan.GatewaySenderAdvisor.GatewaySenderProfile;
-import com.gemstone.gemfire.internal.cache.xmlcache.CacheCreation;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.LoggingThreadGroup;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.EntryOperation;
+import org.apache.geode.cache.asyncqueue.AsyncEventListener;
+import org.apache.geode.cache.wan.GatewayTransportFilter;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.distributed.internal.ResourceEvent;
+import org.apache.geode.distributed.internal.DistributionAdvisor.Profile;
+import org.apache.geode.internal.cache.DistributedRegion;
+import org.apache.geode.internal.cache.EntryEventImpl;
+import org.apache.geode.internal.cache.EventID;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.PartitionedRegionHelper;
+import org.apache.geode.internal.cache.UpdateAttributesProcessor;
+import org.apache.geode.internal.cache.ha.ThreadIdentifier;
+import org.apache.geode.internal.cache.wan.AbstractGatewaySender;
+import org.apache.geode.internal.cache.wan.AbstractGatewaySenderEventProcessor;
+import org.apache.geode.internal.cache.wan.GatewaySenderAttributes;
+import org.apache.geode.internal.cache.wan.parallel.ConcurrentParallelGatewaySenderEventProcessor;
+import org.apache.geode.internal.cache.wan.parallel.ConcurrentParallelGatewaySenderQueue;
+import org.apache.geode.internal.cache.wan.GatewaySenderAdvisor.GatewaySenderProfile;
+import org.apache.geode.internal.cache.xmlcache.CacheCreation;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.LoggingThreadGroup;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
 
 public class ParallelAsyncEventQueueImpl extends AbstractGatewaySender {
   
@@ -190,7 +190,7 @@ public class ParallelAsyncEventQueueImpl extends AbstractGatewaySender {
     pf.manualStart = isManualStart();
     pf.dispatcherThreads = getDispatcherThreads();
     pf.orderPolicy = getOrderPolicy();
-    for (com.gemstone.gemfire.cache.wan.GatewayEventFilter filter : getGatewayEventFilters()) {
+    for (org.apache.geode.cache.wan.GatewayEventFilter filter : getGatewayEventFilters()) {
       pf.eventFiltersClassNames.add(filter.getClass().getName());
     }
     for (GatewayTransportFilter filter : getGatewayTransportFilters()) {
@@ -203,7 +203,7 @@ public class ParallelAsyncEventQueueImpl extends AbstractGatewaySender {
   }
 
   /* (non-Javadoc)
-   * @see com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySender#setModifiedEventId(com.gemstone.gemfire.internal.cache.EntryEventImpl)
+   * @see org.apache.geode.internal.cache.wan.AbstractGatewaySender#setModifiedEventId(org.apache.geode.internal.cache.EntryEventImpl)
    */
   @Override
   protected void setModifiedEventId(EntryEventImpl clonedEvent) {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/SerialAsyncEventQueueImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/SerialAsyncEventQueueImpl.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/SerialAsyncEventQueueImpl.java
index 16ffbde..fe3581f 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/SerialAsyncEventQueueImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/SerialAsyncEventQueueImpl.java
@@ -14,37 +14,37 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.asyncqueue.internal;
+package org.apache.geode.cache.asyncqueue.internal;
 
-import com.gemstone.gemfire.CancelException;
+import org.apache.geode.CancelException;
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.asyncqueue.AsyncEventListener;
-import com.gemstone.gemfire.cache.wan.GatewayTransportFilter;
-import com.gemstone.gemfire.distributed.DistributedLockService;
-import com.gemstone.gemfire.distributed.internal.DistributionAdvisor.Profile;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.distributed.internal.ResourceEvent;
-import com.gemstone.gemfire.internal.cache.EntryEventImpl;
-import com.gemstone.gemfire.internal.cache.EventID;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.RegionQueue;
-import com.gemstone.gemfire.internal.cache.UpdateAttributesProcessor;
-import com.gemstone.gemfire.internal.cache.ha.ThreadIdentifier;
-import com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySender;
-import com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySenderEventProcessor;
-import com.gemstone.gemfire.internal.cache.wan.GatewaySenderAdvisor.GatewaySenderProfile;
-import com.gemstone.gemfire.internal.cache.wan.GatewaySenderAttributes;
-import com.gemstone.gemfire.internal.cache.wan.GatewaySenderConfigurationException;
-import com.gemstone.gemfire.internal.cache.wan.serial.ConcurrentSerialGatewaySenderEventProcessor;
-import com.gemstone.gemfire.internal.cache.wan.serial.SerialGatewaySenderEventProcessor;
-import com.gemstone.gemfire.internal.cache.wan.serial.SerialGatewaySenderQueue;
-import com.gemstone.gemfire.internal.cache.xmlcache.CacheCreation;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.LoggingThreadGroup;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.asyncqueue.AsyncEventListener;
+import org.apache.geode.cache.wan.GatewayTransportFilter;
+import org.apache.geode.distributed.DistributedLockService;
+import org.apache.geode.distributed.internal.DistributionAdvisor.Profile;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.distributed.internal.ResourceEvent;
+import org.apache.geode.internal.cache.EntryEventImpl;
+import org.apache.geode.internal.cache.EventID;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.RegionQueue;
+import org.apache.geode.internal.cache.UpdateAttributesProcessor;
+import org.apache.geode.internal.cache.ha.ThreadIdentifier;
+import org.apache.geode.internal.cache.wan.AbstractGatewaySender;
+import org.apache.geode.internal.cache.wan.AbstractGatewaySenderEventProcessor;
+import org.apache.geode.internal.cache.wan.GatewaySenderAdvisor.GatewaySenderProfile;
+import org.apache.geode.internal.cache.wan.GatewaySenderAttributes;
+import org.apache.geode.internal.cache.wan.GatewaySenderConfigurationException;
+import org.apache.geode.internal.cache.wan.serial.ConcurrentSerialGatewaySenderEventProcessor;
+import org.apache.geode.internal.cache.wan.serial.SerialGatewaySenderEventProcessor;
+import org.apache.geode.internal.cache.wan.serial.SerialGatewaySenderQueue;
+import org.apache.geode.internal.cache.xmlcache.CacheCreation;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.LoggingThreadGroup;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
 
 public class SerialAsyncEventQueueImpl extends AbstractGatewaySender {
 
@@ -219,7 +219,7 @@ public class SerialAsyncEventQueueImpl extends AbstractGatewaySender {
     pf.isPersistenceEnabled = isPersistenceEnabled();
     pf.alertThreshold = getAlertThreshold();
     pf.manualStart = isManualStart();
-    for (com.gemstone.gemfire.cache.wan.GatewayEventFilter filter : getGatewayEventFilters()) {
+    for (org.apache.geode.cache.wan.GatewayEventFilter filter : getGatewayEventFilters()) {
       pf.eventFiltersClassNames.add(filter.getClass().getName());
     }
     for (GatewayTransportFilter filter : getGatewayTransportFilters()) {
@@ -235,7 +235,7 @@ public class SerialAsyncEventQueueImpl extends AbstractGatewaySender {
   }
 
   /* (non-Javadoc)
-   * @see com.gemstone.gemfire.internal.cache.wan.AbstractGatewaySender#setModifiedEventId(com.gemstone.gemfire.internal.cache.EntryEventImpl)
+   * @see org.apache.geode.internal.cache.wan.AbstractGatewaySender#setModifiedEventId(org.apache.geode.internal.cache.EntryEventImpl)
    */
   @Override
   protected void setModifiedEventId(EntryEventImpl clonedEvent) {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/client/AllConnectionsInUseException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/client/AllConnectionsInUseException.java b/geode-core/src/main/java/org/apache/geode/cache/client/AllConnectionsInUseException.java
index d294ba0..22c7824 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/client/AllConnectionsInUseException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/client/AllConnectionsInUseException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.client;
+package org.apache.geode.cache.client;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/client/ClientCache.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/client/ClientCache.java b/geode-core/src/main/java/org/apache/geode/cache/client/ClientCache.java
index b00d1a2..bdc945e 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/client/ClientCache.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/client/ClientCache.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.client;
+package org.apache.geode.cache.client;
 
 import java.net.InetSocketAddress;
 import java.util.Properties;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.*;
-import com.gemstone.gemfire.cache.query.QueryService;
+import org.apache.geode.cache.*;
+import org.apache.geode.cache.query.QueryService;
 
 /**
  * A ClientCache instance controls the life cycle of the local singleton cache in a client. 
@@ -160,7 +160,7 @@ public interface ClientCache extends GemFireCache {
    * Returns the default server pool. If one or more non-default pools were
    * configured, this may return null.
    * @since GemFire 7.0
-   * @see com.gemstone.gemfire.cache.client.Pool
+   * @see org.apache.geode.cache.client.Pool
    */
   public Pool getDefaultPool();
   

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/client/ClientCacheFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/Region.java b/geode-core/src/main/java/org/apache/geode/cache/Region.java
index f70e5de..72333a1 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/Region.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/Region.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -27,17 +27,17 @@ import java.util.Set;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.locks.Lock;
 
-import com.gemstone.gemfire.cache.client.ClientRegionFactory;
-import com.gemstone.gemfire.cache.client.Pool;
-import com.gemstone.gemfire.cache.client.SubscriptionNotEnabledException;
-import com.gemstone.gemfire.cache.query.FunctionDomainException;
-import com.gemstone.gemfire.cache.query.NameResolutionException;
-import com.gemstone.gemfire.cache.query.QueryInvalidException;
-import com.gemstone.gemfire.cache.query.QueryInvocationTargetException;
-import com.gemstone.gemfire.cache.query.QueryService;
-import com.gemstone.gemfire.cache.query.SelectResults;
-import com.gemstone.gemfire.cache.query.TypeMismatchException;
-import com.gemstone.gemfire.cache.snapshot.RegionSnapshotService;
+import org.apache.geode.cache.client.ClientRegionFactory;
+import org.apache.geode.cache.client.Pool;
+import org.apache.geode.cache.client.SubscriptionNotEnabledException;
+import org.apache.geode.cache.query.FunctionDomainException;
+import org.apache.geode.cache.query.NameResolutionException;
+import org.apache.geode.cache.query.QueryInvalidException;
+import org.apache.geode.cache.query.QueryInvocationTargetException;
+import org.apache.geode.cache.query.QueryService;
+import org.apache.geode.cache.query.SelectResults;
+import org.apache.geode.cache.query.TypeMismatchException;
+import org.apache.geode.cache.snapshot.RegionSnapshotService;
 
 /** Manages subregions and cached data. Each region
  * can contain multiple subregions and entries for data.
@@ -49,10 +49,10 @@ import com.gemstone.gemfire.cache.snapshot.RegionSnapshotService;
  * The Region interface basically contains two set of APIs: Region management
  * APIs; and (potentially) distributed operations on entries. Non-distributed
  * operations on entries
  * are provided by the inner interface, {@link com.gemstone.gemfire.cache.Region.Entry}.
  * <p>
  *
  * Each {@link com.gemstone.gemfire.cache.Cache} defines a single top region called the root region.
  * User applications can use the root region to create subregions
  * for isolated name space and object grouping.
  * <p>
@@ -241,7 +241,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * <p>
    * Does not update any <code>CacheStatistics</code>.
    *
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @see CacheListener#afterRegionInvalidate
    */
@@ -257,7 +257,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * Does not update any <code>CacheStatistics</code>.
    * @param aCallbackArgument a user-defined parameter to pass to callback events
    *        triggered by this method. Can be null. Should be serializable.
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for <code>Scope.GLOBAL</code>
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws IllegalArgumentException if aCallbackArgument is not serializable
    * @see CacheListener#afterRegionInvalidate
@@ -313,7 +313,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *
    * @throws CacheWriterException if a CacheWriter aborts the operation; if this
    *         occurs some subregions may have already been successfully destroyed.
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @see CacheListener#afterRegionDestroy
    * @see CacheWriter#beforeRegionDestroy
@@ -334,7 +334,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *        triggered by this method. Can be null. Should be serializable.
    * @throws CacheWriterException if a CacheWriter aborts the operation; if this
    *         occurs some subregions may have already been successfully destroyed.
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws IllegalArgumentException if aCallbackArgument is not serializable
    * @see CacheListener#afterRegionDestroy
@@ -455,7 +455,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws CacheWriterException if a CacheWriter aborts the destroyRegion
    *         operation; if this occurs some subregions may have already been
    *         successfully destroyed.
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws UnsupportedOperationException If the region is a partitioned region
    *
@@ -499,7 +499,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         <a href="AttributesFactory.html#creationConstraints">region creation constraints</a>
    *         with a region of the same name in another cache in the distributed system
    *         or with this (parent) region.
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws RegionExistsException if a subregion by the specified name already exists
    * @throws UnsupportedOperationException If the region is a partitioned region
@@ -580,7 +580,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws NullPointerException if the key is null
    * @throws IllegalArgumentException if the key does not meet
    *         the serializability requirements
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out doing a {@link Cache#getSearchTimeout search} for distributed or getting a distributed lock for Scope.GLOBAL
    * @throws CacheLoaderException if a cache loader throws an exception, or if
    *         the cache loader returns an object that is not serializable and this
@@ -642,7 +642,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * is not found and can't be loaded
    * @throws NullPointerException if key is null
    * @throws IllegalArgumentException if aCallbackArgument is not serializable
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out doing a {@link Cache#getSearchTimeout search} for distributed or getting a distributed lock for Scope.GLOBAL
    * @throws CacheLoaderException if a cache loader throws an exception, or if
    *         the cache loader returns an object that is not serializable and this
@@ -682,7 +682,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         is null (use invalidate instead), or if the key or value do not
    *         meet serializability requirements
    * @throws ClassCastException if key does not satisfy the keyConstraint
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
    * @throws PartitionedRegionStorageException if the operation could not be completed on a partitioned region.
@@ -727,7 +727,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if key, value, or
    *         aCallbackArgument do not meet serializability requirements
    * @throws ClassCastException if key does not satisfy the keyConstraint
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
    * @throws PartitionedRegionStorageException if the operation could not be completed on a partitioned region.
@@ -762,7 +762,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if the key or value
    *         is not serializable and this is a distributed region
    * @throws ClassCastException if key does not satisfy the keyConstraint
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryExistsException if an entry with this key already exists
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -799,7 +799,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if the key, value, or
    *         aCallbackArgument do not meet serializability requirements
    * @throws ClassCastException if key does not satisfy the keyConstraint
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryExistsException if an entry with this key already exists
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -826,7 +826,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws NullPointerException if key is null
    * @throws IllegalArgumentException if the key does not
    *         meet serializability requirements
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryNotFoundException if the entry does not exist in this region
    * @see CacheListener#afterInvalidate
@@ -848,7 +848,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws NullPointerException if key is null
    * @throws IllegalArgumentException if the key or the
    *         aCallbackArgument do not meet serializability requirements
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for <code>Scope.GLOBAL</code>
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryNotFoundException if this entry does not exist in this region
    * @see CacheListener#afterInvalidate
@@ -923,7 +923,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws NullPointerException if key is null
    * @throws IllegalArgumentException if key does not meet
    *         serializability requirements
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws EntryNotFoundException if the entry does not exist in this region
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -959,7 +959,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws NullPointerException if key is null
    * @throws IllegalArgumentException if the key or aCallbackArgument
    *         do not meet serializability requirements
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws EntryNotFoundException if the entry does not exist in this region
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -1574,7 +1574,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws NullPointerException if key is null
    * @throws IllegalArgumentException if key does not meet
    *         serializability requirements
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
    * @see Region#destroy(Object)
@@ -2193,7 +2193,7 @@ public boolean containsKeyOnServer(Object key);
   *         and this map does not permit null keys or values
   * @throws IllegalArgumentException if some property of the specified key
   *         or value prevents it from being stored in this map
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
    * @throws PartitionedRegionStorageException if the operation could not be completed on a partitioned region.
@@ -2227,7 +2227,7 @@ public boolean containsKeyOnServer(Object key);
   *         type for this map (optional)
   * @throws NullPointerException if the specified key or value is null,
   *         and this map does not permit null keys or values (optional)
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
    * @throws PartitionedRegionStorageException if the operation could not be completed on a partitioned region.
@@ -2263,7 +2263,7 @@ public boolean containsKeyOnServer(Object key);
   *         and this map does not permit null keys
   * @throws IllegalArgumentException if some property of a specified key
   *         or value prevents it from being stored in this map
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
    * @throws PartitionedRegionStorageException if the operation could not be completed on a partitioned region.
@@ -2299,7 +2299,7 @@ public boolean containsKeyOnServer(Object key);
   *         and this map does not permit null keys or values
   * @throws IllegalArgumentException if some property of the specified key
   *         or value prevents it from being stored in this map
    * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
    * @throws PartitionedRegionStorageException if the operation could not be completed on a partitioned region.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionAccessException.java
----------------------------------------------------------------------
@@ -49,10 +49,10 @@ import com.gemstone.gemfire.cache.snapshot.RegionSnapshotService;
  * APIs; and (potentially) distributed operations on entries. Non-distributed
  * operations on entries
- * are provided by the inner interface, {@link com.gemstone.gemfire.cache.Region.Entry}.
+ * are provided by the inner interface, {@link org.apache.geode.cache.Region.Entry}.
  * <p>
  *
@@ -49,10 +49,10 @@ import com.gemstone.gemfire.cache.snapshot.RegionSnapshotService;
  * <p>
  *
- * Each {@link com.gemstone.gemfire.cache.Cache} defines a single top region called the root region.
+ * Each {@link org.apache.geode.cache.Cache} defines a single top region called the root region.
  * User applications can use the root region to create subregions
  * for isolated name space and object grouping.
@@ -241,7 +241,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * Does not update any <code>CacheStatistics</code>.
    *
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @see CacheListener#afterRegionInvalidate
@@ -257,7 +257,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @param aCallbackArgument a user-defined parameter to pass to callback events
    *        triggered by this method. Can be null. Should be serializable.
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for <code>Scope.GLOBAL</code>
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for <code>Scope.GLOBAL</code>
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws IllegalArgumentException if aCallbackArgument is not serializable
@@ -313,7 +313,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws CacheWriterException if a CacheWriter aborts the operation; if this
    *         occurs some subregions may have already been successfully destroyed.
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @see CacheListener#afterRegionDestroy
@@ -334,7 +334,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws CacheWriterException if a CacheWriter aborts the operation; if this
    *         occurs some subregions may have already been successfully destroyed.
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws IllegalArgumentException if aCallbackArgument is not serializable
@@ -455,7 +455,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         operation; if this occurs some subregions may have already been
    *         successfully destroyed.
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws UnsupportedOperationException If the region is a partitioned region
@@ -499,7 +499,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         with a region of the same name in another cache in the distributed system
    *         or with this (parent) region.
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws RegionExistsException if a subregion by the specified name already exists
@@ -580,7 +580,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if the key does not meet
    *         the serializability requirements
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out doing a {@link Cache#getSearchTimeout search} for distributed or getting a distributed lock for Scope.GLOBAL
    * @throws CacheLoaderException if a cache loader throws an exception, or if
@@ -642,7 +642,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws NullPointerException if key is null
    * @throws IllegalArgumentException if aCallbackArgument is not serializable
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out doing a {@link Cache#getSearchTimeout search} for distributed or getting a distributed lock for Scope.GLOBAL
    * @throws CacheLoaderException if a cache loader throws an exception, or if
@@ -682,7 +682,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         meet serializability requirements
    * @throws ClassCastException if key does not satisfy the keyConstraint
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -727,7 +727,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         aCallbackArgument do not meet serializability requirements
    * @throws ClassCastException if key does not satisfy the keyConstraint
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -762,7 +762,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         is not serializable and this is a distributed region
    * @throws ClassCastException if key does not satisfy the keyConstraint
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryExistsException if an entry with this key already exists
@@ -799,7 +799,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    *         aCallbackArgument do not meet serializability requirements
    * @throws ClassCastException if key does not satisfy the keyConstraint
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryExistsException if an entry with this key already exists
@@ -826,7 +826,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if the key does not
    *         meet serializability requirements
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryNotFoundException if the entry does not exist in this region
@@ -848,7 +848,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if the key or the
    *         aCallbackArgument do not meet serializability requirements
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for <code>Scope.GLOBAL</code>
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for <code>Scope.GLOBAL</code>
    * @throws TimeoutException if timed out getting distributed lock for <code>Scope.GLOBAL</code>
    * @throws EntryNotFoundException if this entry does not exist in this region
@@ -923,7 +923,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if key does not meet
    *         serializability requirements
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws EntryNotFoundException if the entry does not exist in this region
@@ -959,7 +959,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if the key or aCallbackArgument
    *         do not meet serializability requirements
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws EntryNotFoundException if the entry does not exist in this region
@@ -1574,7 +1574,7 @@ public interface Region<K,V>  extends ConcurrentMap<K, V> {
    * @throws IllegalArgumentException if key does not meet
    *         serializability requirements
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -2193,7 +2193,7 @@ public boolean containsKeyOnServer(Object key);
   * @throws IllegalArgumentException if some property of the specified key
   *         or value prevents it from being stored in this map
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -2227,7 +2227,7 @@ public boolean containsKeyOnServer(Object key);
   * @throws NullPointerException if the specified key or value is null,
   *         and this map does not permit null keys or values (optional)
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -2263,7 +2263,7 @@ public boolean containsKeyOnServer(Object key);
   * @throws IllegalArgumentException if some property of a specified key
   *         or value prevents it from being stored in this map
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
@@ -2299,7 +2299,7 @@ public boolean containsKeyOnServer(Object key);
   * @throws IllegalArgumentException if some property of the specified key
   *         or value prevents it from being stored in this map
-   * @throws com.gemstone.gemfire.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
+   * @throws org.apache.geode.distributed.LeaseExpiredException if lease expired on distributed lock for Scope.GLOBAL
    * @throws TimeoutException if timed out getting distributed lock for Scope.GLOBAL
    * @throws CacheWriterException if a CacheWriter aborts the operation
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionDistributionException.java b/geode-core/src/main/java/org/apache/geode/cache/RegionDistributionException.java
index 81ee2b7..d5ab10c 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionDistributionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionDistributionException.java
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 import java.io.*;
 import java.util.*;
-import com.gemstone.gemfire.distributed.Role;
-import com.gemstone.gemfire.distributed.internal.membership.InternalRole;
+import org.apache.geode.distributed.Role;
+import org.apache.geode.distributed.internal.membership.InternalRole;
 
 /**
  * Indicates that an attempt to send a distributed cache event to one or more
  * {@link MembershipAttributes#getRequiredRoles required roles} may have
  * failed.  Failure may be caused by departure of one or more required roles
  * while sending the message to them.  If the region scope is {@linkplain 
  * com.gemstone.gemfire.cache.Scope#DISTRIBUTED_NO_ACK DISTRIBUTED_NO_ACK} or
  * {@linkplain com.gemstone.gemfire.cache.Scope#GLOBAL GLOBAL} then failure
  * may be caused by one or more required roles not acknowledging receipt of
  * the message.
  *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionEvent.java
----------------------------------------------------------------------
@@ -14,20 +14,20 @@
  * failed.  Failure may be caused by departure of one or more required roles
  * while sending the message to them.  If the region scope is {@linkplain 
- * com.gemstone.gemfire.cache.Scope#DISTRIBUTED_NO_ACK DISTRIBUTED_NO_ACK} or
- * {@linkplain com.gemstone.gemfire.cache.Scope#GLOBAL GLOBAL} then failure
+ * org.apache.geode.cache.Scope#DISTRIBUTED_NO_ACK DISTRIBUTED_NO_ACK} or
+ * {@linkplain org.apache.geode.cache.Scope#GLOBAL GLOBAL} then failure
  * may be caused by one or more required roles not acknowledging receipt of
  * the message.
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RegionMembershipListener.java b/geode-core/src/main/java/org/apache/geode/cache/RegionMembershipListener.java
index c4bd33e..beef65f 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/RegionMembershipListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RegionMembershipListener.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedMember;
 
 /**
  * A listener that can be implemented to handle region membership events.
  * 
  * <p>
  * Instead of implementing this interface it is recommended that you extend
  * the {@link com.gemstone.gemfire.cache.util.RegionMembershipListenerAdapter} class.
  * 
  * 
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/RegionReinitializedException.java
----------------------------------------------------------------------
@@ -14,16 +14,16 @@
  * <p>
  * Instead of implementing this interface it is recommended that you extend
- * the {@link com.gemstone.gemfire.cache.util.RegionMembershipListenerAdapter} class.
+ * the {@link org.apache.geode.cache.util.RegionMembershipListenerAdapter} class.
  * 
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/RequiredRoles.java b/geode-core/src/main/java/org/apache/geode/cache/RequiredRoles.java
index a56a749..0f32716 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/RequiredRoles.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/RequiredRoles.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
-import com.gemstone.gemfire.distributed.Role;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.cache.DistributedRegion;
-import com.gemstone.gemfire.internal.cache.LocalRegion;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.distributed.Role;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.cache.DistributedRegion;
+import org.apache.geode.internal.cache.LocalRegion;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.util.*;
 
@@ -29,7 +29,7 @@ import java.util.*;
  * required roles. Configuration of required roles is accomplished using the
  * <code>Region</code>'s {@link MembershipAttributes}. 
  *
  * A {@link com.gemstone.gemfire.distributed.Role Role} may be present in the
  * distributed system even if it the <code>Role</code> is not present in the
  * <code>Region</code> membership. This would occur if none of the members
  * filling that <code>Role</code> currently have a <code>Cache</code> or the
@@ -37,7 +37,7 @@ import java.util.*;
  * considered to be absent for that <code>Region</code>.
  *
  * @deprecated this feature is scheduled to be removed
- * @see com.gemstone.gemfire.distributed.Role
+ * @see org.apache.geode.distributed.Role
  */
 public class RequiredRoles {
   
@@ -93,7 +93,7 @@ public class RequiredRoles {
   }
   
   /**
-   * Returns true if the {@link com.gemstone.gemfire.distributed.Role Role}
+   * Returns true if the {@link org.apache.geode.distributed.Role Role}
    * is currently present in the {@link Region} membership. This returns true
    * only if one or more members filling this role actually have the region
    * currently created. The role may be present in the distributed system even

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/ResourceException.java
----------------------------------------------------------------------
@@ -29,7 +29,7 @@ import java.util.*;
  * <code>Region</code>'s {@link MembershipAttributes}. 
  *
- * A {@link com.gemstone.gemfire.distributed.Role Role} may be present in the
+ * A {@link org.apache.geode.distributed.Role Role} may be present in the
  * distributed system even if it the <code>Role</code> is not present in the
  * <code>Region</code> membership. This would occur if none of the members
diff --git a/geode-core/src/main/java/org/apache/geode/cache/TimeoutException.java b/geode-core/src/main/java/org/apache/geode/cache/TimeoutException.java
index f04f3d8..4cb21ca 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/TimeoutException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/TimeoutException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache;
+package org.apache.geode.cache;
 
 /** Thrown if a <code>netSearch</code> times out without getting a response back from a cache,
  * or when attempting to acquire a distributed lock.
@@ -23,15 +23,15 @@ package com.gemstone.gemfire.cache;
  *
  *
  * @see LoaderHelper#netSearch
- * @see com.gemstone.gemfire.cache.Region#invalidateRegion()
- * @see com.gemstone.gemfire.cache.Region#destroyRegion()
+ * @see org.apache.geode.cache.Region#invalidateRegion()
+ * @see org.apache.geode.cache.Region#destroyRegion()
  * @see Region#createSubregion
  * @see com.gemstone.gemfire.cache.Region#get(Object)
  * @see com.gemstone.gemfire.cache.Region#put(Object, Object)
  * @see com.gemstone.gemfire.cache.Region#create(Object, Object)
  * @see com.gemstone.gemfire.cache.Region#invalidate(Object)
  * @see com.gemstone.gemfire.cache.Region#destroy(Object)
  * @see com.gemstone.gemfire.distributed.DistributedLockService
  * @since GemFire 3.0
  */
 public class TimeoutException extends OperationAbortedException {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/TransactionDataNodeHasDepartedException.java
----------------------------------------------------------------------
@@ -23,15 +23,15 @@ package com.gemstone.gemfire.cache;
  * @see Region#createSubregion
- * @see com.gemstone.gemfire.cache.Region#get(Object)
- * @see com.gemstone.gemfire.cache.Region#put(Object, Object)
- * @see com.gemstone.gemfire.cache.Region#create(Object, Object)
- * @see com.gemstone.gemfire.cache.Region#invalidate(Object)
- * @see com.gemstone.gemfire.cache.Region#destroy(Object)
- * @see com.gemstone.gemfire.distributed.DistributedLockService
+ * @see org.apache.geode.cache.Region#get(Object)
+ * @see org.apache.geode.cache.Region#put(Object, Object)
+ * @see org.apache.geode.cache.Region#create(Object, Object)
+ * @see org.apache.geode.cache.Region#invalidate(Object)
+ * @see org.apache.geode.cache.Region#destroy(Object)
+ * @see org.apache.geode.distributed.DistributedLockService
  * @since GemFire 3.0
  */
diff --git a/geode-core/src/main/java/org/apache/geode/cache/client/ClientCacheFactory.java b/geode-core/src/main/java/org/apache/geode/cache/client/ClientCacheFactory.java
index 96dcde3..0a6ecb0 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/client/ClientCacheFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/client/ClientCacheFactory.java
@@ -15,28 +15,28 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.client;
-
-import com.gemstone.gemfire.cache.CacheClosedException;
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.server.CacheServer;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.internal.GemFireVersion;
-import com.gemstone.gemfire.internal.cache.CacheConfig;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.pdx.PdxInstance;
-import com.gemstone.gemfire.pdx.PdxSerializer;
+package org.apache.geode.cache.client;
+
+import org.apache.geode.cache.CacheClosedException;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.server.CacheServer;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.internal.GemFireVersion;
+import org.apache.geode.internal.cache.CacheConfig;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.pdx.PdxInstance;
+import org.apache.geode.pdx.PdxSerializer;
 
 import java.util.Properties;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.LOCATORS;
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
+import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 
 /**
  * Factory class used to create the singleton {@link ClientCache client cache} and connect to one or more GemFire Cache Servers. If the application wants to connect to GemFire as a peer it should use {@link com.gemstone.gemfire.cache.CacheFactory} instead.
  * <p> Once the factory has been configured using its set* methods you produce a {@link ClientCache} by calling the {@link #create} method.
- * The {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CACHE_XML_FILE}
+ * The {@link org.apache.geode.distributed.ConfigurationProperties#CACHE_XML_FILE}
  * property can be used to specify a cache.xml file to initialize the cache with.
  * The contents of this file must comply with the
  * <code>"doc-files/cache8_0.dtd"</code> file and the top level element must be a <code>client-cache</code> element.
@@ -138,7 +138,7 @@ public class ClientCacheFactory {
    *
    * @param props The initial gemfire properties to be used.
    *              These properties can be overridden using the {@link #set} method
    *              For a full list of valid gemfire properties see {@link com.gemstone.gemfire.distributed.ConfigurationProperties}.
    */
   public ClientCacheFactory(Properties props) {
     if (props == null) {
@@ -149,7 +149,7 @@ public class ClientCacheFactory {
 
   /**
    * Sets a gemfire property that will be used when creating the ClientCache.
    * For a full list of valid gemfire properties see {@link com.gemstone.gemfire.distributed.ConfigurationProperties}.
    *
    * @param name  the name of the gemfire property
    * @param value the value of the gemfire property
@@ -559,7 +559,7 @@ public class ClientCacheFactory {
    * By default setPRSingleHopEnabled is <code>true</code>
    * in which case the client is aware of the location of partitions on servers hosting
    * {@link Region regions} with
-   * {@link com.gemstone.gemfire.cache.DataPolicy#PARTITION}.
+   * {@link org.apache.geode.cache.DataPolicy#PARTITION}.
    * Using this information, the client routes the client cache operations
    * directly to the server which is hosting the required partition for the
    * cache operation using a single network hop.
@@ -572,9 +572,9 @@ public class ClientCacheFactory {
    * to go to the required partition for that cache operation.
    * The client will use fewer network connections to the servers.
    * <p>
    * Caution: for {@link com.gemstone.gemfire.cache.DataPolicy#PARTITION partition} regions
    * with
-   * {@link com.gemstone.gemfire.cache.PartitionAttributesFactory#setLocalMaxMemory(int) local-max-memory}
+   * {@link org.apache.geode.cache.PartitionAttributesFactory#setLocalMaxMemory(int) local-max-memory}
    * equal to zero, no cache operations mentioned above will be routed to those
    * servers as they do not host any partitions.
    *
@@ -646,7 +646,7 @@ public class ClientCacheFactory {
    *  @param pdxReadSerialized true to prefer PdxInstance
    *  @return this ClientCacheFactory
    *  @since GemFire 6.6
-   *  @see com.gemstone.gemfire.pdx.PdxInstance 
+   *  @see org.apache.geode.pdx.PdxInstance 
    */
   public ClientCacheFactory setPdxReadSerialized(boolean pdxReadSerialized) {
     this.cacheConfig.setPdxReadSerialized(pdxReadSerialized);
@@ -15,28 +15,28 @@
 
 /**
- * Factory class used to create the singleton {@link ClientCache client cache} and connect to one or more GemFire Cache Servers. If the application wants to connect to GemFire as a peer it should use {@link com.gemstone.gemfire.cache.CacheFactory} instead.
+ * Factory class used to create the singleton {@link ClientCache client cache} and connect to one or more GemFire Cache Servers. If the application wants to connect to GemFire as a peer it should use {@link org.apache.geode.cache.CacheFactory} instead.
  * <p> Once the factory has been configured using its set* methods you produce a {@link ClientCache} by calling the {@link #create} method.
@@ -138,7 +138,7 @@ public class ClientCacheFactory {
    * @param props The initial gemfire properties to be used.
    *              These properties can be overridden using the {@link #set} method
-   *              For a full list of valid gemfire properties see {@link com.gemstone.gemfire.distributed.ConfigurationProperties}.
+   *              For a full list of valid gemfire properties see {@link org.apache.geode.distributed.ConfigurationProperties}.
    */
   public ClientCacheFactory(Properties props) {
@@ -149,7 +149,7 @@ public class ClientCacheFactory {
   /**
    * Sets a gemfire property that will be used when creating the ClientCache.
-   * For a full list of valid gemfire properties see {@link com.gemstone.gemfire.distributed.ConfigurationProperties}.
+   * For a full list of valid gemfire properties see {@link org.apache.geode.distributed.ConfigurationProperties}.
    *
    * @param name  the name of the gemfire property
@@ -572,9 +572,9 @@ public class ClientCacheFactory {
    * The client will use fewer network connections to the servers.
    * <p>
-   * Caution: for {@link com.gemstone.gemfire.cache.DataPolicy#PARTITION partition} regions
+   * Caution: for {@link org.apache.geode.cache.DataPolicy#PARTITION partition} regions
    * with